@@ -225,11 +225,11 @@ yeccpars2(Other, _, _, _, _, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_0/7}).
 -compile({nowarn_unused_function,  yeccpars2_0/7}).
-yeccpars2_0(S, b04, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'b04', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, b16x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'b16x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_0(S, b64x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_0(S, 'b64x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
 yeccpars2_0(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_0_(Stack),
@@ -250,11 +250,11 @@ yeccpars2_2(_, _, _, _, T, _, _) ->
 
 -dialyzer({nowarn_function, yeccpars2_3/7}).
 -compile({nowarn_unused_function,  yeccpars2_3/7}).
-yeccpars2_3(S, b04, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_3(S, 'b04', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 8, Ss, Stack, T, Ts, Tzr);
-yeccpars2_3(S, b16x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_3(S, 'b16x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_3(S, b64x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_3(S, 'b64x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
 yeccpars2_3(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -279,11 +279,11 @@ yeccpars2_6(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_7/7}).
 -compile({nowarn_unused_function,  yeccpars2_7/7}).
-yeccpars2_7(S, b04, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_7(S, 'b04', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 13, Ss, Stack, T, Ts, Tzr);
-yeccpars2_7(S, b16x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_7(S, 'b16x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 14, Ss, Stack, T, Ts, Tzr);
-yeccpars2_7(S, b64x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_7(S, 'b64x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
 yeccpars2_7(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -312,11 +312,11 @@ yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_11/7}).
 -compile({nowarn_unused_function,  yeccpars2_11/7}).
-yeccpars2_11(S, b04, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_11(S, 'b04', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
-yeccpars2_11(S, b16x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_11(S, 'b16x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_11(S, b64x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_11(S, 'b64x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
 yeccpars2_11(_, _, _, _, T, _, _) ->
  yeccerror(T).
@@ -331,7 +331,7 @@ yeccpars2_12(_, _, _, _, T, _, _) ->
 -dialyzer({nowarn_function, yeccpars2_13/7}).
 -compile({nowarn_unused_function,  yeccpars2_13/7}).
 yeccpars2_13(_S, '=', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_13_\'=\''(Stack),
+ NewStack = 'yeccpars2_13_='(Stack),
  yeccgoto_b16(hd(Ss), '=', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_13(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_13_(Stack),
@@ -340,7 +340,7 @@ yeccpars2_13(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 -dialyzer({nowarn_function, yeccpars2_14/7}).
 -compile({nowarn_unused_function,  yeccpars2_14/7}).
 yeccpars2_14(_S, '=', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_14_\'=\''(Stack),
+ NewStack = 'yeccpars2_14_='(Stack),
  yeccgoto_b16(hd(Ss), '=', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_14(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_14_(Stack),
@@ -355,11 +355,11 @@ yeccpars2_15(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 
 -dialyzer({nowarn_function, yeccpars2_16/7}).
 -compile({nowarn_unused_function,  yeccpars2_16/7}).
-yeccpars2_16(S, b04, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_16(S, 'b04', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
-yeccpars2_16(S, b16x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_16(S, 'b16x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 5, Ss, Stack, T, Ts, Tzr);
-yeccpars2_16(S, b64x, Ss, Stack, T, Ts, Tzr) ->
+yeccpars2_16(S, 'b64x', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 6, Ss, Stack, T, Ts, Tzr);
 yeccpars2_16(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_,_|Nss] = Ss,
@@ -472,11 +472,11 @@ yeccpars2_10_(__Stack0) ->
 '$undefined'
   end | __Stack].
 
--compile({inline,'yeccpars2_13_\'=\''/1}).
--dialyzer({nowarn_function, 'yeccpars2_13_\'=\''/1}).
--compile({nowarn_unused_function,  'yeccpars2_13_\'=\''/1}).
+-compile({inline,'yeccpars2_13_='/1}).
+-dialyzer({nowarn_function, 'yeccpars2_13_='/1}).
+-compile({nowarn_unused_function,  'yeccpars2_13_='/1}).
 -file("xmerl_b64Bin.yrl", 0).
-'yeccpars2_13_\'=\''(__Stack0) ->
+'yeccpars2_13_='(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
 '$undefined'
@@ -492,11 +492,11 @@ yeccpars2_13_(__Stack0) ->
 '$undefined'
   end | __Stack].
 
--compile({inline,'yeccpars2_14_\'=\''/1}).
--dialyzer({nowarn_function, 'yeccpars2_14_\'=\''/1}).
--compile({nowarn_unused_function,  'yeccpars2_14_\'=\''/1}).
+-compile({inline,'yeccpars2_14_='/1}).
+-dialyzer({nowarn_function, 'yeccpars2_14_='/1}).
+-compile({nowarn_unused_function,  'yeccpars2_14_='/1}).
 -file("xmerl_b64Bin.yrl", 0).
-'yeccpars2_14_\'=\''(__Stack0) ->
+'yeccpars2_14_='(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
 '$undefined'
